@@ -687,8 +687,10 @@ void set_stdio_sigs(void)
 		exit(STATE_CRITICAL);
 
 	clean_environ(keep_env_vars, nrpe_user);
-	drop_privileges(nrpe_user, nrpe_group, 0);	/* drop privileges */
-	check_privileges();			/* make sure we're not root */
+
+	/* drop and then check privileges */
+	drop_privileges(nrpe_user, nrpe_group, 0);
+	check_privileges();
 }
 
 void cleanup(void)
@@ -2009,7 +2011,7 @@ int read_packet(int sock, void *ssl_ptr, v2_packet * v2_pkt, v3_packet ** v3_pkt
 
 		packet_ver = ntohs(v2_pkt->packet_version);
 		if (packet_ver != NRPE_PACKET_VERSION_2 && packet_ver != NRPE_PACKET_VERSION_3) {
-			logit(LOG_ERR, "Error: Request packet version was invalid!");
+			logit(LOG_ERR, "Error: (use_ssl == false): Request packet version was invalid!");
 			return -1;
 		}
 
@@ -2037,7 +2039,7 @@ int read_packet(int sock, void *ssl_ptr, v2_packet * v2_pkt, v3_packet ** v3_pkt
 			buffer_size = ntohl(buffer_size);
 			pkt_size += buffer_size;
 			if ((*v3_pkt = calloc(1, pkt_size)) == NULL) {
-				logit(LOG_ERR, "Error: Could not allocate memory for packet");
+				logit(LOG_ERR, "Error: (use_ssl == false): Could not allocate memory for packet");
 				return -1;
 			}
 
@@ -2071,7 +2073,7 @@ int read_packet(int sock, void *ssl_ptr, v2_packet * v2_pkt, v3_packet ** v3_pkt
 
 		packet_ver = ntohs(v2_pkt->packet_version);
 		if (packet_ver != NRPE_PACKET_VERSION_2 && packet_ver != NRPE_PACKET_VERSION_3) {
-			logit(LOG_ERR, "Error: Request packet version was invalid!");
+			logit(LOG_ERR, "Error: (use_ssl == true): Request packet version was invalid!");
 			return -1;
 		}
 
@@ -2104,7 +2106,7 @@ int read_packet(int sock, void *ssl_ptr, v2_packet * v2_pkt, v3_packet ** v3_pkt
 			buffer_size = ntohl(buffer_size);
 			pkt_size += buffer_size;
 			if ((*v3_pkt = calloc(1, pkt_size)) == NULL) {
-				logit(LOG_ERR, "Error: Could not allocate memory for packet");
+				logit(LOG_ERR, "Error: (use_ssl == true): Could not allocate memory for packet");
 				return -1;
 			}
 
@@ -2221,8 +2223,8 @@ int my_system(char *command, int timeout, int *early_timeout, char **output)
 	if (pid == 0) {
 
 		/* get root back so the next call works correctly */
-		if (SETEUID(0) == -1)
-			logit(LOG_ERR, "ERROR: my_system() seteuid(0): %s", strerror(errno));
+		if (SETEUID(0) == -1 && debug)
+			logit(LOG_WARNING, "WARNING: my_system() seteuid(0): %s", strerror(errno));
 
 		drop_privileges(nrpe_user, nrpe_group, 1);	/* drop privileges */
 		close(fd[0]);			/* close pipe for reading */
@@ -2368,6 +2370,9 @@ int drop_privileges(char *user, char *group, int full_drop)
 	struct group *grp;
 	struct passwd *pw;
 
+	if (use_inetd == TRUE)
+		return OK;
+
 	/* set effective group ID */
 	if (group != NULL) {
 
@@ -2493,8 +2498,8 @@ int remove_pid_file(void)
 		return OK;				/* pid file was not written */
 
 	/* get root back so we can delete the pid file */
-	if (SETEUID(0) == -1)
-		logit(LOG_ERR, "ERROR: remove_pid_file() seteuid(0): %s", strerror(errno));
+	if (SETEUID(0) == -1 && debug)
+		logit(LOG_WARNING, "WARNING: remove_pid_file() seteuid(0): %s", strerror(errno));
 
 	if (unlink(pid_file) == -1) {
 		logit(LOG_ERR, "Cannot remove pidfile '%s' - check your privileges.", pid_file);
